==> pycharmPC-251.28774-EAP-CANDIDATE-SNAPSHOT.zip: nis.py <==
# encoding: utf-8
# module nis
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python312/lib/python3.12/lib-dynload/nis.cpython-312-darwin.so
# by generator 1.147
""" This module contains functions for accessing NIS maps. """
# no imports

# functions

def cat(map, domain=None): # real signature unknown; restored from __doc__
    """
    cat(map, domain = defaultdomain)
    Returns the entire map as a dictionary. Optionally domain can be
    specified but it defaults to the system default domain.
    """
    pass

def get_default_domain(): # real signature unknown; restored from __doc__
    """
    get_default_domain() -> str
    Corresponds to the C library yp_get_default_domain() call, returning
    the default NIS domain.
    """
    return ""

def maps(domain=None): # real signature unknown; restored from __doc__
    """
    maps(domain = defaultdomain)
    Returns an array of all available NIS maps within a domain. If domain
    is not specified it defaults to the system default domain.
    """
    pass

def match(key, map, domain=None): # real signature unknown; restored from __doc__
    """
    match(key, map, domain = defaultdomain)
    Corresponds to the C library yp_match() call, returning the value of
    key in the given map. Optionally domain can be specified but it
    defaults to the system default domain.
    """
    pass

# classes

class error(Exception):
    # no doc
    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    __weakref__ = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default
    """list of weak references to the object (if defined)"""



# variables with complex values

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x101cc6c60>'

__spec__ = None # (!) real value is "ModuleSpec(name='nis', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x101cc6c60>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python312/lib/python3.12/lib-dynload/nis.cpython-312-darwin.so')"

==> pycharmPC-251.29188-EAP-CANDIDATE-SNAPSHOT.zip: nis.py <==
# encoding: utf-8
# module nis
# from /opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/nis.cpython-37m-darwin.so
# by generator 1.147
""" This module contains functions for accessing NIS maps. """
# no imports

# functions

def cat(map, domain=None): # real signature unknown; restored from __doc__
    """
    cat(map, domain = defaultdomain)
    Returns the entire map as a dictionary. Optionally domain can be
    specified but it defaults to the system default domain.
    """
    pass

def get_default_domain(): # real signature unknown; restored from __doc__
    """
    get_default_domain() -> str
    Corresponds to the C library yp_get_default_domain() call, returning
    the default NIS domain.
    """
    return ""

def maps(domain=None): # real signature unknown; restored from __doc__
    """
    maps(domain = defaultdomain)
    Returns an array of all available NIS maps within a domain. If domain
    is not specified it defaults to the system default domain.
    """
    pass

def match(key, map, domain=None): # real signature unknown; restored from __doc__
    """
    match(key, map, domain = defaultdomain)
    Corresponds to the C library yp_match() call, returning the value of
    key in the given map. Optionally domain can be specified but it
    defaults to the system default domain.
    """
    pass

# classes

class error(Exception):
    # no doc
    def __init__(self, *args, **kwargs): # real signature unknown
        pass

    __weakref__ = property(lambda self: object(), lambda self, v: None, lambda self: None)  # default
    """list of weak references to the object (if defined)"""



# variables with complex values

__loader__ = None # (!) real value is '<_frozen_importlib_external.ExtensionFileLoader object at 0x105585488>'

__spec__ = None # (!) real value is "ModuleSpec(name='nis', loader=<_frozen_importlib_external.ExtensionFileLoader object at 0x105585488>, origin='/opt/teamcity-agent/system/.persistent_cache/pycharm/pythons4utils/python37/lib/python3.7/lib-dynload/nis.cpython-37m-darwin.so')"
